@@ -11,21 +11,14 @@
 mkdir ~/.gnome2/nautilus-scripts/Gallery
 
 upload=~/.gnome2/nautilus-scripts/Gallery/Upload\ to\ Gallery
-profile=~/.gnome2/nautilus-scripts/Gallery/Upload\ to\ new\ Gallery\ profile
 
 if [ -h "$upload" ]
     then
         unlink "$upload"
 fi
 
-if [ -h "$profile" ]
-    then
-        unlink "$profile"
-fi
 
-
-ln -s `pwd`/Gallery\ Uploader.py "$upload"
-ln -s `pwd`/Upload\ to\ new\ Gallery\ profile.py "$profile"
+ln -s `pwd`/gallery-uploader "$upload"
 
 killall nautilus; nautilus &
 
